intelmq.bots.outputs.restapi package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.outputs.restapi package

## Submodules

## intelmq.bots.outputs.restapi.output module

intelmq.bots.outputs.restapi.output.BOT

  alias of `intelmq.bots.outputs.restapi.output.RestAPIOutputBot`

class intelmq.bots.outputs.restapi.output.RestAPIOutputBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  Send events to a REST API listener through HTTP POST

  auth_token: str = None
  auth_token_name: str = None
  auth_type = None
  hierarchical_output: bool = False
  host: str = None
  init()
  process()
  use_json: bool = True

## Module contents